@@ -46,6 +46,7 @@ replace_paragraph_role = \
               'logocode': '<code>',
               'note': '{{Note|1=',
               'null': '', # special paragraph for Variable, CaseInline, etc.
+              'ol_item': '',
               'paragraph': '',
               'related': '', # used only in one file, probably in error?
               'relatedtopics': '', # used only in one file, probably in error?
@@ -62,6 +63,7 @@ replace_paragraph_role = \
               'tablenexttip': '\n{{Tip|1=',
               'tablenextwarning': '\n{{Warning|1=',
               'tip': '{{Tip|1=',
+              'ul_item': '',
               'variable': '',
               'warning': '{{Warning|1=',
              },
@@ -82,6 +84,7 @@ replace_paragraph_role = \
             'logocode': '</code>\n\n',
             'note': '}}\n\n',
             'null': '', # special paragraph for Variable, CaseInline, etc.
+            'ol_item': '',
             'paragraph': '\n\n',
             'related': '\n\n', # used only in one file, probably in error?
             'relatedtopics': '\n\n', # used only in one file, probably in error?
@@ -98,6 +101,7 @@ replace_paragraph_role = \
             'tablenexttip': '}}\n\n',
             'tablenextwarning': '}}\n\n',
             'tip': '}}\n\n',
+            'ul_item': '',
             'variable': '',
             'warning': '}}\n\n',
            },
@@ -118,6 +122,7 @@ replace_paragraph_role = \
               'logocode': False,
               'note': True,
               'null': False,
+              'ol_item': False,
               'paragraph': False,
               'related': False,
               'relatedtopics': False,
@@ -134,6 +139,7 @@ replace_paragraph_role = \
               'tablenexttip': True,
               'tablenextwarning': True,
               'tip': True,
+              'ul_item': False,
               'variable': False,
               'warning': True,
            }
@@ -205,7 +211,7 @@ def xopen(path, mode, encoding):
     else:
         return open(path, mode)
 
-# used by ecape_help_text
+# used by escape_help_text
 helptagre = re.compile('''<[/]??[a-z_\-]+?(?:| +[a-zA-Z]+?=[\\\\]??".*?") *[/]??>''')
 
 def escape_help_text(text):
@@ -673,7 +679,12 @@ class ListItem(ElementBase):
         for i in self.objects:
             if linebreak:
                 text = text + '<br/>'
-            text = text + i.get_all()
+            ti = i.get_all()
+            # when the object is another list (i.e. nested lists), only the first item
+            # gets the '#' sign in the front by the previous statement
+            # the below re.sub inserts the extra '#' for all additional items of the list
+            ti = re.sub(r'\n\s*#', '\n##', ti)
+            text = text + ti
             linebreak = True
 
         return text + postfix
@@ -991,7 +1002,9 @@ class Switch(SwitchInline):
 
 class Item(ElementBase):
     replace_type = \
-            {'start':{'input': '<code>',
+            {'start':{'acronym' : '\'\'',
+                      'code': '<code>',
+                      'input': '<code>',
                       'keycode': '{{KeyCode|',
                       'tasto': '{{KeyCode|',
                       'litera': '<code>',
@@ -1002,7 +1015,9 @@ class Item(ElementBase):
                       'productname': '',
                       'unknown': '<code>'
                      },
-             'end':{'input': '</code>',
+             'end':{'acronym' : '\'\'',
+                    'code': '</code>',
+                    'input': '</code>',
                     'keycode': '}}',
                     'tasto': '}}',
                     'litera': '</code>',
@@ -1013,7 +1028,9 @@ class Item(ElementBase):
                     'productname': '',
                     'unknown': '</code>'
                    },
-             'templ':{'input': False,
+             'templ':{'acronym': False,
+                      'code': False,
+                      'input': False,
                       'keycode': True,
                       'tasto': True,
                       'litera': False,
@@ -1363,15 +1380,6 @@ class XhpParser(ParserBase):
         ParserBase.__init__(self, filename, follow_embed, embedding_app,
                 current_app, wiki_page_name, lang, XhpFile(), buf.encode('utf-8'))
 
-def loadallfiles(filename):
-    global titles
-    titles = []
-    file = codecs.open(filename, "r", "utf-8")
-    for line in file:
-        title = line.split(";", 2)
-        titles.append(title)
-    file.close()
-
 class WikiConverter(Thread):
     def __init__(self, inputfile, wiki_page_name, lang, outputfile):
         Thread.__init__(self)
@@ -1433,19 +1441,19 @@ def write_redirects():
                 write_link(r, target)
 
 # Main Function
-def convert(generate_redirects, lang, po_root):
+def convert(title_data, generate_redirects, lang, po_root):
     if lang == '':
         print 'Generating the main wiki pages...'
     else:
         print 'Generating the wiki pages for language %s...'% lang
 
+    global titles
+    titles = [t for t in title_data]
     global redirects
     redirects = []
     global images
     images = set()
 
-    loadallfiles("alltitles.csv")
-
     if lang != '':
         sys.stderr.write('Using localizations from "%s"\n'% po_root)
         if not load_localization_data(po_root):
